#
# spec file for package ncftp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ncftp
Version:        3.2.7
Release:        1.2
Summary:        A Comfortable FTP Program
License:        ClArtistic
Group:          Productivity/Networking/Ftp/Clients
URL:            https://www.ncftp.com/
Source:         https://www.ncftp.com/public_ftp/%{name}/%{name}-%{version}-src.tar.xz
Patch0:         ncftp-3.1.8-locale.diff
Patch2:         ncftp-3.1.8-implicit_decl.diff
Patch3:         ncftp-3.2.5-no-date.patch
# PATCH-FIX-OPENSUSE make build reproducible (boo#1084909)
Patch4:         ncftp-3.2.6-no-uname.patch
Patch5:         ncftp-gcc10-gBm.patch
BuildRequires:  dos2unix
BuildRequires:  ncurses-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This program has been in service on UNIX systems since 1991 and is a
popular alternative to the standard FTP program, %{_bindir}/ftp. NcFTP
offers many ease-of-use and performance enhancements over the stock FTP
client and runs on a wide variety of UNIX platforms as well as
operating systems like Microsoft Windows and Apple Mac OS X.

%prep
%setup -q
%patch -P 0 -p1
%patch -P 2
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

%build
export CFLAGS="%{optflags} -D_LARGEFILE64_SOURCE"
%configure \
  --enable-ssp
make %{?_smp_mflags} STRIP=/bin/touch

%install
dos2unix doc/*.txt
make DESTDIR=%{buildroot} install %{?_smp_mflags} STRIP=/bin/touch

%files
%defattr(-,root,root)
%doc *.txt
%doc doc/*.txt
%doc doc/html
%{_bindir}/ncftp
%{_bindir}/ncftpbatch
%{_bindir}/ncftpbookmarks
%{_bindir}/ncftpget
%{_bindir}/ncftpls
%{_bindir}/ncftpput
%{_bindir}/ncftpspooler
%{_mandir}/man1/ncftp.1*
%{_mandir}/man1/ncftpbatch.1*
%{_mandir}/man1/ncftpget.1*
%{_mandir}/man1/ncftpls.1*
%{_mandir}/man1/ncftpput.1*
%{_mandir}/man1/ncftpspooler.1*

%changelog
* Mon Mar 11 2024 jun wang <jgwang@suse.com>
- Update to version 3.2.7
  * Portability fixes
  * Fix parsing MLSD listings with absolute pathnames for files
  * Default to automatic resumption of downloads
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Jun  8 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Fix build with GCC 10:
  * Set gBm as extern only in bookmark.h
- Add ncftp-gcc10-gBm.patch
* Thu Jun 14 2018 bwiedemann@suse.com
- Add ncftp-3.2.6-no-uname.patch to make build reproducible (boo#1084909)
* Sun Jan 15 2017 astieger@suse.com
- update to 3.2.6:
  * If a recursive download operation is also requested with delete mode,
    attempt to remove empty directories after all files have completed
    successfully.
  * No longer trying to utime() after every single block on downloads,
    which could cause noticable performance degradation when the local
    filesystem was not local.
  * Changed behavior of resuming downloads where the timestamp wasn't
    preserved (because of the utime change, above). The new behavior is
    to resume the download when the local copy has a recent timestamp
    (less than a week).
  * You can now disable use of MFMT like you could similarly disable
    SITE UTIME (e.g., "-o noMFMT" and "-o noSITE_UTIME").
  * Now able to use sendfile() for uploads, on Linux/FreeBSD/Mac.
    Progress reports work too, with a small performance penalty.
    Ncftpput has a "-s" option to toggle whether it is used (defaults
    to on in ncftpput and ncftpbatch, off in ncftp).
  * Ncftpbatch/spooler now use larger buffers for pathnames, allowing
    for deeper directory trees.
  * Ncftpbatch/spooler now interpret a received SIGUSR1 as a hint to
    exit when the current file has finished.
  * Ncftpbatch/spooler now interpret a received SIGUSR2 to request it
    to stop sleeping and recheck the queue immediately.
  * Ncftpbatch/spooler's spool files now allow for you to specify that
    the local and/or remote file be renamed after a successful transfer.
  * Ncftpbatch/spooler now a little less chatty by reducing the number
    of PWD/CWD operations.
  * Ncftpbatch/spooler now log some xfer stats in its general log file,
    and ncftpspooler has a new "-x" option to specify a separate
    xfer log file.
  * Ncftpbatch/spooler now use a larger default maximum for its log
    file (10 MiB rather than 200 kB), and ncftpspooler has an -O command
    line option that can set this limit. Use "-O 0" for no maximum.
  * Ncftpbatch/spooler now try to present time in local timezone rather
    than UTC where possible.
  * Ncftpbatch/spooler now support multiple items per transaction
    (spool) file.
* Tue Jun  2 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
* Tue Feb 18 2014 andreas.stieger@gmx.de
- update to 3.2.5
  + ncftpls now prefers that you omit the leading dash when you use the -x
    option.  For example, if you wanted to try "ls -lrt", then try doing
    "ncftpls -x lrt" rather than "ncftpls -x -lrt".
  + If a server's MLSx output returns both the "UNIX.mode" and the "perm"
    parameters, UNIX.mode will take precedence
  + confirm-close is now off by default.
- license is the Clarified Artistic License
- use correct line endings for documentation
- remove __DATE__ from binary added patches:
  * ncftp-3.2.5-no-date.patch
- use source URLs
* Fri Aug 27 2010 anicka@suse.cz
- update to 3.2.4
  * Fixed a bug in Ncftpget/put/ls which could ignore the username (-u)
  and password (-p) command line parameters.
  * Ncftpget and ncftpput can now read $HOME/.ncftp/bookmarks and take a
  bookmark name in place of a hostname.
  * Support for local validation of DNSSEC when combined with libraries
  available from the DNSSEC Tools project (Thanks, Robert Story).
  * Microsoft disabled recursive directory listings altogether when fixing
* Wed Aug  5 2009 puzel@novell.com
- reduce buildrequires to ncurses-devel
* Thu Jul 30 2009 pascal.bleser@opensuse.org
- update to 3.2.3:
  * Large File Support has been updated internally to use newer
    APIs, rather than the transitional API
  * you can now specify an IP address for binding the local end
  of socket
  * bug fixed where binding an ephemeral port number in a
  specified range (rare) may not have used all available
  retries for binding
  * local writes now "retry" when the write returns less than the
  full number of bytes specified, and will call write() again
  to write out the remaining bytes.
  * fixed a bug where the global firewall pref files were not
  read if the user's home directory was the root directory
  * using MFMT command to set remote timestamps, if available, in
  preference to SITE UTIME or MDTM
  * host, user, and pass fields have been increased in size
  * bug fixed where the firewall preference files were ignored
  for the root user
  * Ncftpls now has a "-Z" option that will disable doing the
  actual directory listing; this is useful for use with the
  "-Y" option to send a raw FTP command without doing a listing
- added missing BuildRequires in spec file
- dropped ncftp-3.2.0-mkdir_parents.diff, merged upstream
* Mon Sep  8 2008 hvogel@suse.de
- Update to 3.2.2
  * Fixed an assertion failure in NcFTP's "help" command
  * PASV mode will now be retried, in case of a transient failure.
  * Fixed feature detection for WS_FTP servers.
  * HOME, END, and DEL keys may work on more terminal types
  * You can now type just ".." or the absolute path of a directory
  * Added command aliases "mv" and "ll" which alias to "rename"
    and "dir"
  * ncftpbatch now has an -L option to specify the name of a
    log file
  * The default connect timeout has been reduced from 30 to 10
    seconds
* Mon Aug 13 2007 crrodriguez@suse.de
- Update ncftp to 3.2.1 [#299587]
- Now a little more tolerant of FTP servers who send their internal network IP addresses in their PASV response. When thi
- Resuming of uploads can now work for servers that do not support REST + STOR. The APPE command will be used instead.
- Fixed problem with Resume All [R!] in ncftp, which was just appending to subsequent files rather than resuming them. (Thanks, Terry Brown)
- ncftpput for version 3.2.0 did not work correctly when both -f and -c/-C were used
- Various small fixes.
* Tue Sep 12 2006 tpatzig@suse.de
- Update to 3.2.0 including:
  o Makefile fixes (obsoletes ncftp-3.1.8-DESTDIR.diff)
  o Makefile fix (ncftp-3.2.0-mkdir_parents.diff)
  o ncftpls can now try to attempt to filter the files with a wildcard
    with the new -i option.
  o ncftpls can also now behave similar to /usr/bin/find, with the new -g
    option.  When invoked with -gg, it appends a slash to directory pathnames
    so you can distinguish files from directories.
  o Fixed a problem with ASCII translation where a CR+LF may not have
    been converted to the local text EOLN format if the CR+LF was split
    over an internal block boundary.
  o You can now edit remote files.
  o Progress meters now output to stderr.
  o You can now resume uploads when uploading into a temporary file
  o Fixes for Cygwin.
  o Some fixes for largefile support on Windows.
  o You can now resume transfers in ASCII mode, rather than just binary.
  o Fixed a problem with recursive uploads for Windows.
  o You can now use an empty password if your user account does not have
    a password.
  o Fixed a problem in the "ls" implementation for international
    month names.
  o Fixed a bug where Type of Service socket options were being set
    with IPPROTO_TCP instead of IPPROTO_IP.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 schwab@suse.de
- Don't strip binaries.
* Fri Sep 23 2005 ro@suse.de
- fix implicit declaration
* Thu Jul 21 2005 mmj@suse.de
- Update to 3.1.9 including:
  o Renamed internal libraru function getline() to gl_getline()
    to avoid namespace collision with glibc.
  o Recognize additional error response codes to SITE UTIME, to
    prevent using it if the server doesn't support it.
  o If the server does not support setting timestamps in MDTM,
    quit trying it if it fails the first time.
  o Do not allow control characters such as NUL, CR, LF in FTP
    URLs, to avoid command injection
  o Fixed a problem where a timed-out transfer may have been
    detected but still locked up the process
  o ncftpget and ncftpput now accept a "-C" parameter which is
    similar to the "-c" option (ftp "cat" mode), where stdin
    (stdout) is not used and the filename is specified as a
    parameter instead. This is useful if you don't want to
    specify a password on the command line.
  o ncftpput now allows the "-m" option in conjunction with the
    "-c" or "-C" options.
* Wed Aug 11 2004 mmj@suse.de
- Update to 3.1.8 including:
  o Ncftpget, ncftpput, and ncftpls now try to erase the
    arguments to the -u/-p/-j (user, password, account) options
    so they do not show in a "ps" command
  o Recognize broken IBM mainframe FTP servers and work around them.
  o Working around a problem with ProFTPD 1.2.9 and later which
    would cause recursive downloads to fail.
  o Fixed a bug where ncftpput in recursive mode could lock up if
    you used a trailing slash on the directory to upload.
  o For the malicious server problem that was addressed in 3.1.5,
    enhanced the fix for better compatibility with mainframe FTP
    servers.
  o Ncftpget, ncftpput, and ncftpls, and ncftp's open command now
    accept an additional advanced option (-o) which lets you do
    things like disable NcFTP's use of SITE UTIME, FEAT, HELP
    SITE, etc.
  o A couple of looping problems with ncftpbatch fixed.
  o Bug fixed with the upload socket buffer not being set
  o The utility programs now accept "-" for the config file name
    used with "-f" to denote standard input.
  o Bug fixed with ncftpput when using both -c and -A
* Wed Feb  4 2004 mmj@suse.de
- Update to 3.1.7 including:
  o Fixed a memory leak introduced in 3.1.6.
  o Fixed problem where it was assumed that daylight saving's
    time occurred at the same time each year for all timezones.
  o Bug fixed with running a shell escape.
  o Ncftpget now uses passive-with-fall-back-to-port mode like
    ncftpput and ncftpls.
  o Problem fixed with "ls -a" where occasionally a row with
    ".." and another file would be omitted.
  o Ncftpbatch now uses the UTC timezone for spool files.
  o The configure script can now detect when the config.cache
    file has been improperly recycled from a machine with a
    different OS.
  o The Windows version now uses the USERPROFILE environment
    variable, if it was set, as the location of the user's home
    directory.
  o Recognize broken DG/UX servers and work around them.
* Thu Oct 16 2003 mmj@suse.de
- Don't build as root
- Update to 3.1.6 including:
  o Fixed an important bug that was causing socket leaks on Windows.
  o Added support for GCC 3.4 precompiled headers.
  o Aborting transfers is now more robust.
  o Re-fixed a problem where high ASCII characters at the NcFTP
    prompt could cause it to exit.
  o Bug fixed where timeouts may not have worked.
  o To the improved ASCII handling from 3.1.5, added another case
    where we workaround files sent by a buggy FTP server
    implementation whose files have CR+CR+LF end-of-lines.
  o Bug fixed where an upload filename could have been limited to
    127 characters.
  o Firewall exception hosts are no longer case sensitive.
  o Bug fixed in ncftpput's "-c" option so it works with the "-f"
    option
  o Ncftpbatch will now try to temporarily skip a failing host in
    the current run
  o Bug fixed where a several minute delay would be incurred if
    you tried to transfer a file that did not exist.
  o For the malicious server problem that was addressed in 3.1.5,
    enhanced the fix for better compatibility with Serv-U and WS_FTP
    servers.
* Thu Nov 14 2002 mmj@suse.de
- Update to 3.1.5, mainly bugfix release
* Tue Sep 17 2002 ro@suse.de
- Removed bogus self-provides
* Wed May 15 2002 mmj@suse.de
- Update to 3.1.3, several impovements and bugfixes
* Thu Apr 18 2002 uli@suse.de
- fixed to build
* Wed Dec  5 2001 uli@suse.de
- update -> 3.0.4 (bugfixes)
* Tue May 22 2001 uli@suse.de
- update -> 3.0.3 (bug #7741)
* Tue Apr 17 2001 uli@suse.de
- 64 bit fix
* Thu Mar 29 2001 uli@suse.de
- fixed for gcc >2.95
* Thu Mar  8 2001 uli@suse.de
- added install section so man pages get zipped again
* Sun Nov 26 2000 egger@suse.de
- Reworked specfile.
- Added RPM Group Tag.
- Updated to 3.0.2.
- Use BuildRoot.
* Thu Sep 28 2000 ro@suse.de
- fixed spec
* Mon Aug 28 2000 daniele@suse.de
- Updated to 3.0.1
- fixed some spec-file entries
* Sat Mar  4 2000 uli@suse.de
- moved man page to /usr/share
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jun 15 1999 uli@suse.de
- update -> 2.4.3 (security fix)
* Thu Jan  2 1997 florian@suse.de
- update to version 2.4.2
* Thu Jan  2 1997 florian@suse.de
- Update auf neue Version 2.4.1.
